all.Digms<-function(){
     cat("\n")
     note_for_Dig_input()
     cat("\n")
     note_for_close_window()
     DigMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),bw=c(0),scr=c(0),D=c(0),tau=c(0),c=c(0))
     DigMSpar<-edit(DigMSpar)
##     DigMSpar<-ymscheck(DigMSpar)
     cat("\n")
     Dig.ms(length(DigMSpar$subject),DigMSpar$c,DigMSpar$tau,DigMSpar$D,DigMSpar$scr,DigMSpar$bw,DigMSpar$age,DigMSpar$Gender)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Dig_output()
     show(samplesStats("*"))
     cat("\n")
     C<-Digcpr(DigMSpar$D,DigMSpar$tau)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (ng/mL)")
     show(coutput)  
     cat("\n") 
     cal.again()
}